@@ -23,14 +23,18 @@ seriate.matrix <- function(x,
   method = "PCA",
   control = NULL,
   margin = c(1L, 2L),
-  ...)
+  rep = 1L,
+  ...) {
+  if (rep > 1L)
+    return(seriate_rep(x, method, control, rep = rep, margin = margin, ...))
+
   .seriate_array_helper(x,
     method,
     control,
     margin,
     datatype = "matrix",
     ...)
-
+  }
 
 
 
