@@ -20,16 +20,6 @@ C     EPS is unused this is to supress the warning.
 C       Initialize R RNG
       CALL getrngstate()
 
-      IF (IVERB == 1) THEN
-C          PRINT *,'Anti-Robinson Seriation by branch-and-bound'
-C          PRINT *,'based on bbwrcg.f by Brusco, and Stahl, S. (2005)'
-          CALL FPRINTF('Anti-Robinson seriation by branch-and-bound',
-     1 43, 0.0, 0.0)
-          CALL FPRINTF('based on bburcg.f by Brusco, '
-     1 //'and Stahl, S. (2005)', 53, 0.0, 0.0)
-          CALL FPRINTF('', 0, 0.0, 0.0)
-      ENDIF
-
       OLDM=0
       CHECKS=0
 
@@ -99,10 +89,14 @@ C
  853      CONTINUE
  852    CONTINUE
  851  CONTINUE
-C
+C Run heuristic to find a good objective value
+      IF (IVERB == 1) THEN
+        CALL intpr('Run heuristic', -1, IVERB, 0)
+      ENDIF
+
       ZBEST = 0.0D0
 C      DO 3500 JJJ = 1,100
-      DO 3500 JJJ = 1,20
+      DO 3500 JJJ = 1,100
         DO I = 1,N
           UNSEL(I) = I
           Q(I) = 0
@@ -181,12 +175,12 @@ C
         END DO
         IF(ITRIG.EQ.1) GO TO 3502
         IF(Z.GT.ZBEST) ZBEST = Z
+
  3500 CONTINUE
 C      WRITE(2,3505) ZBEST
       IF (IVERB == 1) THEN
 C          WRITE(*,3505) ZBEST
-          CALL FPRINTF('HEURISTIC OBJ VALUE: %12.3f', 28,
-     1 DBLE(ZBEST), 0.0)
+          CALL dblepr('HEURISTIC OBJ VALUE', -1, DBLE(ZBEST), 1)
       ENDIF
 C 3505 FORMAT(' HEURISTIC OBJ VALUE ',F20.4)
       Z = ZBEST-1
@@ -208,8 +202,8 @@ C
       CHECKS=CHECKS+1
       IF (IVERB == 1 .AND. M .GT. OLDM) THEN
 C          WRITE (*,6000) M+1, CHECKS
-          CALL FPRINTF('reached position %5.0f with %9.0f checks',
-     1 41, DBLE(M+1), DBLE(CHECKS))
+          CALL intpr('reached position', -1, M+1, 1)
+          CALL intpr('with following number of checks', -1, CHECKS, 1)
 C 6000 FORMAT('reached position ', I5, ' with ', I9, ' checks')
           OLDM=M
       ENDIF
@@ -238,7 +232,7 @@ C
           Z=ZBD
           IF (IVERB == 1) THEN
 C              WRITE(*,*) 'Eval =',z
-              CALL FPRINTF('Eval =  %10.3f', 14, DBLE(z), 0.0)
+              CALL dblepr('Eval', -1, DBLE(z), 1)
           ENDIF
           DO I = 1,N
             X(I)=Q(I)
@@ -258,7 +252,7 @@ C              WRITE(*,*) 'Eval =',z
               R4=Q(J)
               IDX1=IDX1+D(R1,R4,R3)
               IDX2=IDX2+D(R1,R3,R4)
-C  
+C
             END DO
 C
           END DO
@@ -309,7 +303,7 @@ C
               R4=Q(J)
               IDX1=IDX1+D(R1,R2,R4)
               IDX2=IDX2+D(R1,R3,R4)
-C  
+C
               IDX1=IDX1+D(R1,R4,R3)
               IDX2=IDX2+D(R1,R4,R2)
 C
@@ -391,10 +385,9 @@ C 70   FORMAT(30I3)
 C
   9   IF (IVERB == 1) THEN
 C          PRINT *, 'total number of checks: ', CHECKS
-          CALL FPRINTF('total number of checks: %10.0f',
-     1 32, DBLE(CHECKS), 0.0)
+          CALL intpr('total number of checks', -1, CHECKS, 1)
       ENDIF
- 
+
 C    Return R RNG
       CALL Putrngstate()
 
